@@ -19,13 +19,18 @@ def is_type(valid_type):
     :returns: a function which returns True its input is an instance of valid_type, and raises TypeError otherwise
     :rtype: callable
     """
+
     def validate(value, should_raise=True):
         if not isinstance(value, valid_type):
             if should_raise:
-                raise TypeError("Expected value of type {expected}, actual value was of type {actual}.".format(
-                    expected=valid_type, actual=type(value)))
+                raise TypeError(
+                    "Expected value of type {expected}, actual value was of type {actual}.".format(
+                        expected=valid_type, actual=type(value)
+                    )
+                )
             return False
         return True
+
     return validate
 
 
@@ -37,6 +42,7 @@ def list_of(validate_item):
     :returns: a function which returns True its input is an list of valid items, and raises TypeError otherwise
     :rtype: callable
     """
+
     def validate(value, should_raise=True):
         validate_type = is_type(list)
         if not validate_type(value, should_raise=should_raise):
@@ -51,6 +57,7 @@ def list_of(validate_item):
                     raise
                 return False
         return True
+
     return validate
 
 
@@ -63,6 +70,7 @@ def dict_of(validate_key, validate_item):
     :returns: a function which returns True its input is an dict of valid items, and raises TypeError otherwise
     :rtype: callable
     """
+
     def validate(value, should_raise=True):
         validate_type = is_type(dict)
         if not validate_type(value, should_raise=should_raise):
@@ -85,6 +93,7 @@ def dict_of(validate_key, validate_item):
                     raise
                 return False
         return True
+
     return validate
 
 
@@ -96,6 +105,7 @@ def one_of(*validators):
               otherwise
     :rtype: callable
     """
+
     def validate(value, should_raise=True):
         if any(validate(value, should_raise=False) for validate in validators):
             return True
@@ -103,6 +113,7 @@ def one_of(*validators):
         if should_raise:
             raise TypeError("value did not match any allowable type")
         return False
+
     return validate
 
 
