@@ -4,7 +4,9 @@ from six import string_types
 
 from samtranslator.model.intrinsics import ref
 from samtranslator.model.intrinsics import make_conditional
+from samtranslator.model.intrinsics import is_intrinsic
 from samtranslator.model.exceptions import InvalidDocumentException, InvalidTemplateException
+import json
 
 
 class OpenApiEditor(object):
@@ -15,9 +17,11 @@ class OpenApiEditor(object):
     empty skeleton.
     """
 
-    _X_APIGW_INTEGRATION = 'x-amazon-apigateway-integration'
+    _X_APIGW_INTEGRATION = "x-amazon-apigateway-integration"
+    _X_APIGW_TAG_VALUE = "x-amazon-apigateway-tag-value"
+    _X_APIGW_CORS = "x-amazon-apigateway-cors"
     _CONDITIONAL_IF = "Fn::If"
-    _X_ANY_METHOD = 'x-amazon-apigateway-any-method'
+    _X_ANY_METHOD = "x-amazon-apigateway-any-method"
     _ALL_HTTP_METHODS = ["OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "PATCH"]
     _DEFAULT_PATH = "$default"
 
@@ -26,17 +30,20 @@ class OpenApiEditor(object):
         Initialize the class with a swagger dictionary. This class creates a copy of the Swagger and performs all
         modifications on this copy.
 
-        :param dict doc: Swagger document as a dictionary
-        :raises ValueError: If the input Swagger document does not meet the basic Swagger requirements.
+        :param dict doc: OpenApi document as a dictionary
+        :raises ValueError: If the input OpenApi document does not meet the basic OpenApi requirements.
         """
         if not OpenApiEditor.is_valid(doc):
-            raise ValueError("Invalid OpenApi document. "
-                             "Invalid values or missing keys for 'openapi' or 'paths' in 'DefinitionBody'.")
+            raise ValueError(
+                "Invalid OpenApi document. "
+                "Invalid values or missing keys for 'openapi' or 'paths' in 'DefinitionBody'."
+            )
 
         self._doc = copy.deepcopy(doc)
         self.paths = self._doc["paths"]
         self.security_schemes = self._doc.get("components", {}).get("securitySchemes", {})
-        self.definitions = self._doc.get('definitions', {})
+        self.definitions = self._doc.get("definitions", {})
+        self.tags = self._doc.get("tags", [])
 
     def get_path(self, path):
         """
@@ -83,10 +90,12 @@ class OpenApiEditor(object):
 
         # Extract the integration uri out of a conditional if necessary
         uri = integration.get("uri")
+        if not isinstance(uri, dict):
+            return ""
         if self._CONDITIONAL_IF in uri:
             arn = uri[self._CONDITIONAL_IF][1].get("Fn::Sub")
         else:
-            arn = uri.get("Fn::Sub")
+            arn = uri.get("Fn::Sub", "")
 
         # Extract lambda integration (${LambdaName.Arn}) and split ".Arn" off from it
         regex = "([A-Za-z0-9]+\.Arn)"
@@ -141,9 +150,11 @@ class OpenApiEditor(object):
         method = self._normalize_method_name(method)
 
         path_dict = self.get_path(path)
-        return self.has_path(path, method) and \
-            isinstance(path_dict[method], dict) and \
-            self.method_has_integration(path_dict[method])  # Integration present and non-empty
+        return (
+            self.has_path(path, method)
+            and isinstance(path_dict[method], dict)
+            and self.method_has_integration(path_dict[method])
+        )  # Integration present and non-empty
 
     def add_path(self, path, method=None):
         """
@@ -160,16 +171,21 @@ class OpenApiEditor(object):
         if not isinstance(path_dict, dict):
             # Either customers has provided us an invalid Swagger, or this class has messed it somehow
             raise InvalidDocumentException(
-                [InvalidTemplateException("Value of '{}' path must be a dictionary according to Swagger spec."
-                                          .format(path))])
+                [
+                    InvalidTemplateException(
+                        "Value of '{}' path must be a dictionary according to Swagger spec.".format(path)
+                    )
+                ]
+            )
 
         if self._CONDITIONAL_IF in path_dict:
             path_dict = path_dict[self._CONDITIONAL_IF][1]
 
         path_dict.setdefault(method, {})
 
-    def add_lambda_integration(self, path, method, integration_uri,
-                               method_auth_config=None, api_auth_config=None, condition=None):
+    def add_lambda_integration(
+        self, path, method, integration_uri, method_auth_config=None, api_auth_config=None, condition=None
+    ):
         """
         Adds aws_proxy APIGW integration to the given path+method.
 
@@ -192,17 +208,17 @@ class OpenApiEditor(object):
 
         path_dict = self.get_path(path)
         path_dict[method][self._X_APIGW_INTEGRATION] = {
-            'type': 'aws_proxy',
-            'httpMethod': 'POST',
-            'payloadFormatVersion': '1.0',
-            'uri': integration_uri
+            "type": "aws_proxy",
+            "httpMethod": "POST",
+            "payloadFormatVersion": "2.0",
+            "uri": integration_uri,
         }
 
         if path == self._DEFAULT_PATH and method == self._X_ANY_METHOD:
             path_dict[method]["isDefaultRoute"] = True
 
         # If 'responses' key is *not* present, add it with an empty dict as value
-        path_dict[method].setdefault('responses', {})
+        path_dict[method].setdefault("responses", {})
 
         # If a condition is present, wrap all method contents up into the condition
         if condition:
@@ -227,6 +243,66 @@ class OpenApiEditor(object):
         for path, value in self.paths.items():
             yield path
 
+    def add_timeout_to_method(self, api, path, method_name, timeout):
+        """
+        Adds a timeout to this path/method.
+        
+        :param dict api: Reference to the related Api's properties as defined in the template.
+        :param string path: Path name
+        :param string method_name: Method name
+        :param int timeout: Timeout amount, in milliseconds
+        """
+        normalized_method_name = self._normalize_method_name(method_name)
+        for method_definition in self.get_method_contents(self.get_path(path)[normalized_method_name]):
+            if self.method_definition_has_integration(method_definition):
+                method_definition[self._X_APIGW_INTEGRATION]["timeoutInMillis"] = timeout
+
+    def add_path_parameters_to_method(self, api, path, method_name, path_parameters):
+        """
+        Adds path parameters to this path + method
+        
+        :param dict api: Reference to the related Api's properties as defined in the template.
+        :param string path: Path name
+        :param string method_name: Method name
+        :param list path_parameters: list of strings of path parameters
+        """
+        normalized_method_name = self._normalize_method_name(method_name)
+        for method_definition in self.get_method_contents(self.get_path(path)[normalized_method_name]):
+            # create path parameter list
+            # add it here if it doesn't exist, merge with existing otherwise.
+            method_definition.setdefault("parameters", [])
+            for param in path_parameters:
+                # find an existing parameter with this name if it exists
+                existing_parameter = next(
+                    (
+                        existing_parameter
+                        for existing_parameter in method_definition.get("parameters", [])
+                        if existing_parameter.get("name") == param
+                    ),
+                    None,
+                )
+                if existing_parameter:
+                    # overwrite parameter values for existing path parameter
+                    existing_parameter["in"] = "path"
+                    existing_parameter["required"] = True
+                else:
+                    parameter = {"name": param, "in": "path", "required": True}
+                    method_definition.get("parameters").append(parameter)
+
+    def add_payload_format_version_to_method(self, api, path, method_name, payload_format_version="2.0"):
+        """
+        Adds a payload format version to this path/method.
+
+        :param dict api: Reference to the related Api's properties as defined in the template.
+        :param string path: Path name
+        :param string method_name: Method name
+        :param string payload_format_version: payload format version sent to the integration
+        """
+        normalized_method_name = self._normalize_method_name(method_name)
+        for method_definition in self.get_method_contents(self.get_path(path)[normalized_method_name]):
+            if self.method_definition_has_integration(method_definition):
+                method_definition[self._X_APIGW_INTEGRATION]["payloadFormatVersion"] = payload_format_version
+
     def add_authorizers_security_definitions(self, authorizers):
         """
         Add Authorizer definitions to the securityDefinitions part of Swagger.
@@ -262,21 +338,22 @@ class OpenApiEditor(object):
                     # If no integration given, then we don't need to process this definition (could be AWS::NoValue)
                     if not self.method_definition_has_integration(method_definition):
                         continue
-                    existing_security = method_definition.get('security', [])
+                    existing_security = method_definition.get("security", [])
                     if existing_security:
                         return
                     authorizer_list = []
                     if authorizers:
                         authorizer_list.extend(authorizers.keys())
                     security_dict = dict()
-                    security_dict[default_authorizer] = self._get_authorization_scopes(api_authorizers,
-                                                                                       default_authorizer)
+                    security_dict[default_authorizer] = self._get_authorization_scopes(
+                        api_authorizers, default_authorizer
+                    )
                     authorizer_security = [security_dict]
 
                     security = authorizer_security
 
                     if security:
-                        method_definition['security'] = security
+                        method_definition["security"] = security
 
     def add_auth_to_method(self, path, method_name, auth, api):
         """
@@ -315,12 +392,12 @@ class OpenApiEditor(object):
             if not self.method_definition_has_integration(method_definition):
                 continue
 
-            existing_security = method_definition.get('security', [])
+            existing_security = method_definition.get("security", [])
 
             security_dict = dict()
             security_dict[authorizer_name] = []
 
-            if authorizer_name != 'NONE':
+            if authorizer_name != "NONE":
                 method_authorization_scopes = authorizers[authorizer_name].get("AuthorizationScopes")
                 if authorization_scopes:
                     method_authorization_scopes = authorization_scopes
@@ -332,7 +409,91 @@ class OpenApiEditor(object):
             # This assumes there are no authorizers already configured in the existing security block
             security = existing_security + authorizer_security
             if security:
-                method_definition['security'] = security
+                method_definition["security"] = security
+
+    def add_tags(self, tags):
+        """
+        Adds tags to the OpenApi definition using an ApiGateway extension for tag values.
+
+        :param dict tags: dictionary of tagName:tagValue pairs.
+        """
+        for name, value in tags.items():
+            # find an existing tag with this name if it exists
+            existing_tag = next((existing_tag for existing_tag in self.tags if existing_tag.get("name") == name), None)
+            if existing_tag:
+                # overwrite tag value for an existing tag
+                existing_tag[self._X_APIGW_TAG_VALUE] = value
+            else:
+                tag = {"name": name, self._X_APIGW_TAG_VALUE: value}
+                self.tags.append(tag)
+
+    def add_cors(
+        self,
+        allow_origins,
+        allow_headers=None,
+        allow_methods=None,
+        expose_headers=None,
+        max_age=None,
+        allow_credentials=None,
+    ):
+        """
+        Add CORS configuration to this Api to _X_APIGW_CORS header in open api definition
+
+        Following this guide:
+        https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-cors.html
+        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apigatewayv2-api-cors.html
+
+        :param list/dict allowed_origins: Comma separate list of allowed origins.
+            Value can also be an intrinsic function dict.
+        :param list/dict allowed_headers: Comma separated list of allowed headers.
+            Value can also be an intrinsic function dict.
+        :param list/dict allowed_methods: Comma separated list of allowed methods.
+            Value can also be an intrinsic function dict.
+        :param list/dict expose_headers: Comma separated list of allowed methods.
+            Value can also be an intrinsic function dict.
+        :param integer/dict max_age: Maximum duration to cache the CORS Preflight request. Value is set on
+            Access-Control-Max-Age header. Value can also be an intrinsic function dict.
+        :param bool/None allowed_credentials: Flags whether request is allowed to contain credentials.
+        """
+        ALLOW_ORIGINS = "allowOrigins"
+        ALLOW_HEADERS = "allowHeaders"
+        ALLOW_METHODS = "allowMethods"
+        EXPOSE_HEADERS = "exposeHeaders"
+        MAX_AGE = "maxAge"
+        ALLOW_CREDENTIALS = "allowCredentials"
+        cors_headers = [ALLOW_ORIGINS, ALLOW_HEADERS, ALLOW_METHODS, EXPOSE_HEADERS, MAX_AGE, ALLOW_CREDENTIALS]
+        cors_configuration = self._doc.get(self._X_APIGW_CORS, dict())
+
+        # intrinsics will not work if cors configuration is defined in open api and as a property to the HttpApi
+        if allow_origins and is_intrinsic(allow_origins):
+            cors_configuration_string = json.dumps(allow_origins)
+            for header in cors_headers:
+                # example: allowOrigins to AllowOrigins
+                keyword = header[0].upper() + header[1:]
+                cors_configuration_string = cors_configuration_string.replace(keyword, header)
+            cors_configuration_dict = json.loads(cors_configuration_string)
+            cors_configuration.update(cors_configuration_dict)
+
+        else:
+            if allow_origins:
+                cors_configuration[ALLOW_ORIGINS] = allow_origins
+            if allow_headers:
+                cors_configuration[ALLOW_HEADERS] = allow_headers
+            if allow_methods:
+                cors_configuration[ALLOW_METHODS] = allow_methods
+            if expose_headers:
+                cors_configuration[EXPOSE_HEADERS] = expose_headers
+            if max_age is not None:
+                cors_configuration[MAX_AGE] = max_age
+            if allow_credentials is True:
+                cors_configuration[ALLOW_CREDENTIALS] = allow_credentials
+
+        self._doc[self._X_APIGW_CORS] = cors_configuration
+
+    def has_api_gateway_cors(self):
+        if self._doc.get(self._X_APIGW_CORS):
+            return True
+        return False
 
     @property
     def openapi(self):
@@ -345,6 +506,9 @@ class OpenApiEditor(object):
         # Make sure any changes to the paths are reflected back in output
         self._doc["paths"] = self.paths
 
+        if self.tags:
+            self._doc["tags"] = self.tags
+
         if self.security_schemes:
             self._doc.setdefault("components", {})
             self._doc["components"]["securitySchemes"] = self.security_schemes
@@ -360,10 +524,11 @@ class OpenApiEditor(object):
         :return: True, if data is valid OpenApi
         """
 
-        if bool(data) and isinstance(data, dict) and isinstance(data.get('paths'), dict):
+        if bool(data) and isinstance(data, dict) and isinstance(data.get("paths"), dict):
             if bool(data.get("openapi")):
                 return OpenApiEditor.safe_compare_regex_with_string(
-                    OpenApiEditor.get_openapi_version_3_regex(), data["openapi"])
+                    OpenApiEditor.get_openapi_version_3_regex(), data["openapi"]
+                )
         return False
 
     @staticmethod
@@ -373,15 +538,7 @@ class OpenApiEditor(object):
 
         :return dict: Dictionary of a skeleton swagger document
         """
-        return {
-            'openapi': '3.0.1',
-            'info': {
-                'version': '1.0',
-                'title': ref('AWS::StackName')
-            },
-            'paths': {
-            }
-        }
+        return {"openapi": "3.0.1", "info": {"version": "1.0", "title": ref("AWS::StackName")}, "paths": {}}
 
     @staticmethod
     def _get_authorization_scopes(authorizers, default_authorizer):
@@ -391,8 +548,10 @@ class OpenApiEditor(object):
         :param default_authorizer: name of the default authorizer
         """
         if authorizers is not None:
-            if authorizers[default_authorizer] \
-               and authorizers[default_authorizer].get("AuthorizationScopes") is not None:
+            if (
+                authorizers[default_authorizer]
+                and authorizers[default_authorizer].get("AuthorizationScopes") is not None
+            ):
                 return authorizers[default_authorizer].get("AuthorizationScopes")
         return []
 
@@ -411,7 +570,7 @@ class OpenApiEditor(object):
             return method
 
         method = method.lower()
-        if method == 'any':
+        if method == "any":
             return OpenApiEditor._X_ANY_METHOD
         else:
             return method
@@ -427,4 +586,4 @@ class OpenApiEditor(object):
 
     @staticmethod
     def get_path_without_trailing_slash(path):
-        return re.sub(r'{([a-zA-Z0-9._-]+|proxy\+)}', '*', path)
+        return re.sub(r"{([a-zA-Z0-9._-]+|proxy\+)}", "*", path)
